@@ -18,7 +18,6 @@
 #' @inheritSection calculatePCA Feature selection
 #' @inheritSection calculatePCA Using reduced dimensions
 #' @inheritSection calculatePCA Using alternative Experiments
-#' 
 #' @return 
 #' For \code{calculateNMF}, a numeric matrix is returned containing the NMF coordinates for each cell (row) and dimension (column).
 #' 
@@ -64,7 +63,12 @@ NULL
 
     # RcppML doesn't use transposed data
     nmf_x <- t(nmf_out$h)
-    attr(nmf_x, "basis") <- nmf_out$w
+    rownames(nmf_x) <- colnames(x)
+    colnames(nmf_x) <- paste0("NMF", seq_len(ncol(nmf_x)))
+    nmf_basis <- nmf_out$w
+    rownames(nmf_basis) <- rownames(x)
+    colnames(nmf_basis) <- paste0("NMF", seq_len(ncol(nmf_basis)))
+    attr(nmf_x, "basis") <- nmf_basis
 
     nmf_x
 }
@@ -76,15 +80,15 @@ setMethod("calculateNMF", "ANY", .calculate_nmf)
 #' @export
 #' @rdname runNMF
 #' @importFrom SummarizedExperiment assay
-setMethod("calculateNMF", "SummarizedExperiment", function(x, ..., exprs_values="logcounts") {
-    .calculate_nmf(assay(x, exprs_values), ...)
+setMethod("calculateNMF", "SummarizedExperiment", function(x, ..., exprs_values="logcounts", assay.type=exprs_values) {
+    .calculate_nmf(assay(x, assay.type), ...)
 })
 
 #' @export
 #' @rdname runNMF
 setMethod("calculateNMF", "SingleCellExperiment",
-    function(x, ..., exprs_values="logcounts", dimred=NULL, n_dimred=NULL) {
-    mat <- .get_mat_from_sce(x, exprs_values=exprs_values, dimred=dimred, n_dimred=n_dimred)
+    function(x, ..., exprs_values="logcounts", dimred=NULL, n_dimred=NULL, assay.type=exprs_values) {
+    mat <- .get_mat_from_sce(x, assay.type=assay.type, dimred=dimred, n_dimred=n_dimred)
     .calculate_nmf(mat, transposed=!is.null(dimred), ...)
 })
 
