@@ -90,6 +90,9 @@ NULL
     }
 
     if (use_densvis) {
+        if (!requireNamespace("densvis", quietly = TRUE)) {
+            stop("densvis is not installed.")
+        }
         umap_out <- do.call(densvis::densmap, args)
     } else {
         umap_out <- do.call(uwot::umap, args)
